==> haskell-generics-sop-0.5.1.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generics-sop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 generics-sop
version:              0.5.1.1
visibility:           public
id:                   generics-sop-0.5.1.1-LZv5fMoLnJa1RwH0cLY37k
key:                  generics-sop-0.5.1.1-LZv5fMoLnJa1RwH0cLY37k
license:              BSD-3-Clause
maintainer:           andres@well-typed.com
author:
    Edsko de Vries <edsko@well-typed.com>, Andres Löh <andres@well-typed.com>

synopsis:             Generic Programming using True Sums of Products
description:
    A library to support the definition of generic functions.
    Datatypes are viewed in a uniform, structured way:
    the choice between constructors is represented using an n-ary
    sum, and the arguments of each constructor are represented using
    an n-ary product.

    The module "Generics.SOP" is the main module of this library and contains
    more detailed documentation.

    Since version 0.4.0.0, this package is now based on
    @<https://hackage.haskell.org/package/sop-core sop-core>@. The core package
    contains all the functionality of n-ary sums and products, whereas this
    package provides the datatype-generic programming support on top.

    Examples of using this library are provided by the following
    packages:

    * @<https://hackage.haskell.org/package/basic-sop basic-sop>@ basic examples,

    * @<https://hackage.haskell.org/package/pretty-sop pretty-sop>@ generic pretty printing,

    * @<https://hackage.haskell.org/package/lens-sop lens-sop>@ generically computed lenses,

    * @<https://hackage.haskell.org/package/json-sop json-sop>@ generic JSON conversions.

    A detailed description of the ideas behind this library is provided by
    the paper:

    * Edsko de Vries and Andres Löh.
    <http://www.andres-loeh.de/TrueSumsOfProducts True Sums of Products>.
    Workshop on Generic Programming (WGP) 2014.

category:             Generics
abi:                  5e8b8eae25c443e9b3ee804c21920c02
exposed:              True
exposed-modules:
    Generics.SOP Generics.SOP.BasicFunctors Generics.SOP.Classes
    Generics.SOP.Constraint Generics.SOP.Dict Generics.SOP.GGP
    Generics.SOP.Instances Generics.SOP.Metadata Generics.SOP.NP
    Generics.SOP.NS Generics.SOP.Sing Generics.SOP.TH
    Generics.SOP.Type.Metadata Generics.SOP.Universe

import-dirs:          /usr/lib/ghc-9.0.1/site-local/generics-sop-0.5.1.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/generics-sop-0.5.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/generics-sop-0.5.1.1
hs-libraries:         HSgenerics-sop-0.5.1.1-LZv5fMoLnJa1RwH0cLY37k
depends:
    base-4.15.0.0 ghc-prim-0.7.0
    sop-core-0.5.0.1-AXbFIEygwaRHSMwVmZvzfr template-haskell-2.17.0.0
    th-abstraction-0.4.3.0-DBpnRpG8EZgFebz88L1kOA

haddock-interfaces:
    /usr/share/doc/haskell-generics-sop/html/generics-sop.haddock

haddock-html:         /usr/share/doc/haskell-generics-sop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generics-sop-0.5.1.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generics-sop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 generics-sop
version:              0.5.1.1
visibility:           public
id:                   generics-sop-0.5.1.1-3bFDOH8KLJNGftETI5ShQz
key:                  generics-sop-0.5.1.1-3bFDOH8KLJNGftETI5ShQz
license:              BSD-3-Clause
maintainer:           andres@well-typed.com
author:
    Edsko de Vries <edsko@well-typed.com>, Andres Löh <andres@well-typed.com>

synopsis:             Generic Programming using True Sums of Products
description:
    A library to support the definition of generic functions.
    Datatypes are viewed in a uniform, structured way:
    the choice between constructors is represented using an n-ary
    sum, and the arguments of each constructor are represented using
    an n-ary product.

    The module "Generics.SOP" is the main module of this library and contains
    more detailed documentation.

    Since version 0.4.0.0, this package is now based on
    @<https://hackage.haskell.org/package/sop-core sop-core>@. The core package
    contains all the functionality of n-ary sums and products, whereas this
    package provides the datatype-generic programming support on top.

    Examples of using this library are provided by the following
    packages:

    * @<https://hackage.haskell.org/package/basic-sop basic-sop>@ basic examples,

    * @<https://hackage.haskell.org/package/pretty-sop pretty-sop>@ generic pretty printing,

    * @<https://hackage.haskell.org/package/lens-sop lens-sop>@ generically computed lenses,

    * @<https://hackage.haskell.org/package/json-sop json-sop>@ generic JSON conversions.

    A detailed description of the ideas behind this library is provided by
    the paper:

    * Edsko de Vries and Andres Löh.
    <http://www.andres-loeh.de/TrueSumsOfProducts True Sums of Products>.
    Workshop on Generic Programming (WGP) 2014.

category:             Generics
abi:                  cdac59984c747ebe7c46597dd4733304
exposed:              True
exposed-modules:
    Generics.SOP Generics.SOP.BasicFunctors Generics.SOP.Classes
    Generics.SOP.Constraint Generics.SOP.Dict Generics.SOP.GGP
    Generics.SOP.Instances Generics.SOP.Metadata Generics.SOP.NP
    Generics.SOP.NS Generics.SOP.Sing Generics.SOP.TH
    Generics.SOP.Type.Metadata Generics.SOP.Universe

import-dirs:          /usr/lib/ghc-9.0.2/site-local/generics-sop-0.5.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/generics-sop-0.5.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/generics-sop-0.5.1.1
hs-libraries:         HSgenerics-sop-0.5.1.1-3bFDOH8KLJNGftETI5ShQz
depends:
    base-4.15.1.0 ghc-prim-0.7.0
    sop-core-0.5.0.2-3jnDWqiXqcyAzV81XsfWbk template-haskell-2.17.0.0
    th-abstraction-0.4.3.0-KTsBdnGbxBE1GYg4VOLAou

haddock-interfaces:
    /usr/share/doc/haskell-generics-sop/html/generics-sop.haddock

haddock-html:         /usr/share/doc/haskell-generics-sop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
